@@ -1,15 +1,15 @@
 # -*-cperl-*-
 #
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
-# Copyright (c) Ashish Gulhati <biz-btc at hash.neo.tc>
+# Copyright (c) 2016 Ashish Gulhati <biz-btc at ashish dot neomailbox.com>
 #
-# $Id: lib/Business/Bitcoin.pm v1.051 Tue Oct 16 22:26:58 PDT 2018 $
+# $Id: lib/Business/Bitcoin.pm v1.10 Thu Dec 29 13:32:18 2016 -0500 $
 
 use strict;
 
 package Business::Bitcoin;
 
-use 5.010000;
+use 5.008001;
 use warnings;
 use strict;
 
@@ -18,30 +18,28 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.051 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.10 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
-  my %arg = @_;
-  return undef unless $arg{XPUB};
-  return undef if $arg{StartIndex} and $arg{StartIndex} =~ /\D/;
-  unlink $arg{DB} if $arg{Clobber} and $arg{DB} ne ':memory:';
-  my $db = DBI->connect("dbi:SQLite:dbname=$arg{DB}", undef, undef, {AutoCommit => 1});
+  my %args = @_;
+  return undef unless $args{XPUB};
+  return undef if $args{StartIndex} and $args{StartIndex} =~ /\D/;
+  unlink $args{DB} if $args{Clobber};
+  my $db = DBI->connect("dbi:SQLite:dbname=$args{DB}","","");
   my @tables = $db->tables('%','%','requests','TABLE');
   unless ($tables[0]) {
-    if ($arg{Create}) {
+    if ($args{Create}) {
       return undef unless $db->do('CREATE TABLE requests (
 		                                         reqid INTEGER PRIMARY KEY AUTOINCREMENT,
 		                                         amount int NOT NULL,
                                                          address text,
-                                                         reference text UNIQUE,
-		                                         created int NOT NULL,
-                                                         processed int,
-                                                         status text
+                                                         refid text UNIQUE,
+		                                         created int NOT NULL
 		                                        );');
       return undef unless $db->do('CREATE INDEX idx_requests_address ON requests(address);');
-      return undef unless $db->do('CREATE INDEX idx_requests_reference ON requests(reference);');
-      my $startindex = $arg{StartIndex} || 0;
+      return undef unless $db->do('CREATE INDEX idx_requests_refid ON requests(refid);');
+      my $startindex = $args{StartIndex} || 0;
       $startindex--;
       return unless $db->do("INSERT INTO SQLITE_SEQUENCE values ('requests',$startindex);");
     }
@@ -49,32 +47,32 @@ sub new {
       return undef;
     }
   }
-  bless { XPUB => $arg{XPUB}, DB => $db, PATH => $arg{Path} || 'penultimate' }, $class;
+  bless { XPUB => $args{XPUB}, DB => $db, KUCMD => $args{kucmd} || '/usr/local/bin/ku' }, $class;
 }
 
 sub request {                      # Create a Bitcoin payment request
-  my ($self, %arg) = @_;
-  return undef if $arg{Amount} !~ /^\d+$/;
+  my ($self, %args) = @_;
+  return undef if $args{Amount} !~ /^\d+$/;
 
   # Workaround for SQLite not starting sequence from 0 when asked to in new()
   my $startindex = $self->db->selectcol_arrayref("SELECT seq from SQLITE_SEQUENCE WHERE name='requests';")->[0];
   my %forcezero; %forcezero = ( StartIndex => 0 ) if $startindex == -1;
 
-  my $req = new Business::Bitcoin::Request (_BizBTC => $self, %arg, %forcezero);
+  my $req = new Business::Bitcoin::Request (_BizBTC => $self, %args, %forcezero);
 }
 
 sub findreq {                      # Retrieve a previously created request
-  my ($self, %arg) = @_;
-  my $req = _find Business::Bitcoin::Request (_BizBTC => $self, %arg);
+  my ($self, %args) = @_;
+  my $req = _find Business::Bitcoin::Request (_BizBTC => $self, %args);
 }
 
 sub AUTOLOAD {
   my $self = shift; (my $auto = $AUTOLOAD) =~ s/.*:://;
   return if $auto eq 'DESTROY';
-  if ($auto =~ /^(xpub|path|db)$/x) {
+  if ($auto =~ /^(xpub|db|kucmd)$/x) {
     $self->{"\U$auto"} = shift if (defined $_[0]);
   }
-  if ($auto =~ /^(xpub|path|db|version)$/x) {  
+  if ($auto =~ /^(xpub|db|version|kucmd)$/x) {  
     return $self->{"\U$auto"};
   }
   else {
@@ -84,16 +82,14 @@ sub AUTOLOAD {
 
 1; # End of Business::Bitcoin
 
-__END__
-
 =head1 NAME
 
 Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.051 $
- $Date: Tue Oct 16 22:26:58 PDT 2018 $
+ $Revision: 1.10 $
+ $Date: Thu Dec 29 13:32:18 2016 -0500 $
 
 =head1 SYNOPSIS
 
@@ -126,50 +122,15 @@ wallet private key offline.
 =head1 HOW TO USE
 
 To start receiving Bitcoin payments online, create an HD wallet using
-a BIP-32 HD wallet app such as Electrum, get the Extended Public Key
-for the wallet (a string beginning with "xpub") and plug it into the
-constructor's XPUB argument.
+any HD wallet app (e.g. Electrum, Bitcoin Armory), get the
+"Master Public Key" for the wallet (a string beginning with "xpub")
+and plug it into the constructor's XPUB argument).
 
 Now you can receive online payments as outlined above, while keeping
-your private key secure offline or in a hardware wallet. You should
-take all precautions to ensure that your XPUB key on the server is
-also safe, as its compromise can weaken your security, though it can't
-in itself lead to the loss of any Bitcoin.
-
-To make this work right you need to find the correct key to plug into
-the XPUB parameter, so that the addresses generated by
-Business::Bitcoin match those your wallet uses to receive payments.
-
-If you're using the Electrum wallet, you can just use its Master
-Public Key (from the menubar select Wallet -> Master Public Keys). To
-use this key you must also set the 'Path' parameter to 'electrum' when
-creating a new Business::Bitcoin object (or via the path() accessor).
-
-By default, however, the addresses Business::Bitcoin generates will be
-for the key derivation path k/i, where k is the path of the extended
-public key provided in the XPUB parameter, and i is the index of the
-address being generated.
-
-This provides the flexibility to use Business::Bitcoin in conjunction
-with any wallet, because different wallets use different key
-derivation paths to generate addresses. e.g. Electrum uses the path
-"m/0/i", MultiBit HD uses "m/a'/0/i", Mycellium uses
-"m/44'/0'/a'/0/i", etc. (m is the "Master Public Key" and a is the
-"account" index).
-
-To have Business::Bitcoin generate addresses matching those generated
-by your wallet, ensure that the XPUB parameter contains the public key
-for the penultimate element of your wallet's key derivation path. So
-for Electrum that would be m/0, for MultiBit HD m/a'/0, and for
-Mycellium m/44'/0'/a'/0
-
-Some wallets may not readily provide the key for this element of the
-path. In that case you can find it using a tool such as "ku" from
-Pycoin L<https://github.com/richardkiss/pycoin> or a JavaScript tool
-such as the one at L<http://bip32.org/>. It's probably best never to
-paste private keys in web forms however, so if your key derivation
-path requires the private key, best to use something like the "ku"
-tool on an offline machine.
+your private key secure offline. You should still take all precautions
+to ensure that your XPUB key on the server is also safe, as its
+compromise can weaken your security, though it can't in itself lead to
+the loss of any Bitcoin.
 
 =head1 METHODS
 
@@ -182,7 +143,7 @@ requests database. The following named arguments are required:
 
 DB - The filename of the requests database
 
-XPUB - The extended public key for the wallet receiving payments
+XPUB - The master public key for the wallet receiving payments
 
 =back
 
@@ -202,17 +163,10 @@ addresses before starting to receive payments using this
 module. Only relevant when Create is true and a new
 requests table is being created. Ignored when an existing
 requests table is being used; in that case the index is generated by the
-database. By default, receiving addresses will be generated starting
+database. By default, receiving addresses will be generaed starting
 from the first one, at index 0.
 
-Path - Set the path option for the key provided in the XPUB
-parameter. By default this is set to 'penultimate' which means the
-XPUB parameter should hold the key of the penultimate path element as
-described above. You can also set this to 'electrum', in which case
-you can directly provide ELectrum's "Master Public Key" in the XPUB
-parameter. (The master public key is at path "m", whereas the
-penultimate one to generate Electrum compatible addresses is at
-"m/0").
+kucmd - The filename of the "ku" command from pycoin. Default is '/usr/local/bin/ku'.
 
 =back
 
@@ -235,11 +189,9 @@ The following optional named arguments can be provided:
 Confirmations - The number of confirmations needed to verify payment
 of this request. The default is 5.
 
-Reference - Optional reference ID to be associated with the request,
-to facilitate integration with existing ordering systems. If a
-reference ID is provided it should be unique for each request.
-
-=back
+Reference - Optional reference ID to be associated with the requst, to
+facilitate integration with existing ordering systems. If you provide
+a reference ID it should be unique for each request.
 
 =head2 findreq
 
@@ -277,14 +229,11 @@ The filename of the requests DB file.
 
 =head2 xpub
 
-The extended public key from which all receiving keys are generated.
+The master public key from which all receiving keys are generated.
 
-=head2 path
+=head2 kucmd
 
-The path option for the XPUB key. This can either be 'penultimate'
-(the default) in which case addresses are generated using the path
-"k/i", or 'electrum' in which case addresses are generated using the
-path "k/0/i", where "k" is the path of the XPUB key provided.
+The pathname of the "ku" command from pycoin.
 
 =head2 version
 
@@ -292,6 +241,13 @@ The version number of this module. Read only.
 
 =head1 PREREQUISITES
 
+=head2 pycoin
+
+The "ku" command from pycoin is used to generate new receiving
+addresses. You can get pycoin from:
+
+    https://github.com/richardkiss/pycoin
+
 =head2 DBD::SQLite
 
 Used to keep track of payment requests.
@@ -303,7 +259,7 @@ blockchain.info API.
 
 =head1 AUTHOR
 
-Ashish Gulhati, C<< <biz-btc at hash.neo.tc> >>
+Ashish Gulhati, C<< <biz-btc at ashish dot neomailbox.com> >>
 
 =head1 BUGS
 
@@ -341,12 +297,10 @@ L<http://search.cpan.org/dist/Business-Bitcoin/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) Ashish Gulhati.
+Copyright (c) 2016 Ashish Gulhati. All rights reserved.
 
-This software package is Open Software; you can use, redistribute,
-and/or modify it under the terms of the Open Artistic License 2.0.
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
-Please see L<http://www.opensoftwr.org/oal20.txt> for the full license
-terms, and ensure that the license grant applies to you before using
-or modifying this software. By using or modifying this software, you
-indicate your agreement with the license terms.
+See http://dev.perl.org/licenses/ for more information.
